from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Paraset(_message.Message):
    __slots__ = ("header", "command", "set_num", "paraset_byte54", "paraset_byte53", "paraset_byte52", "paraset_byte51", "paraset_byte50", "paraset_byte49", "paraset_byte48", "paraset_byte47", "paraset_byte46", "paraset_byte45", "paraset_byte44", "paraset_byte43", "paraset_byte42", "paraset_byte41", "paraset_byte40", "paraset_byte39", "paraset_byte38", "paraset_byte37", "paraset_byte36", "paraset_byte35", "paraset_byte34", "paraset_byte33", "paraset_byte32", "paraset_byte31", "paraset_byte30", "paraset_byte29", "paraset_byte28", "paraset_byte27", "paraset_byte26", "paraset_byte25", "paraset_byte24", "paraset_byte23", "paraset_byte22", "paraset_byte21", "paraset_byte20", "paraset_byte19", "paraset_byte18", "paraset_byte17", "paraset_byte16", "paraset_byte15", "paraset_byte14", "paraset_byte13", "paraset_byte12", "paraset_byte11", "paraset_byte10", "paraset_byte9", "paraset_byte8", "paraset_byte7", "paraset_byte6", "paraset_byte5", "paraset_byte4", "paraset_byte3", "paraset_byte2", "paraset_byte1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    SET_NUM_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE54_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE53_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE52_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE51_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE50_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE49_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE48_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE47_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE46_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE45_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE44_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE43_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE42_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE41_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE40_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE39_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE38_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE37_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE36_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE35_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE34_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE33_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE32_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE31_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE30_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE29_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE28_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE27_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE26_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE25_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE24_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE23_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE22_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE21_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE20_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE19_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE18_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE17_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE16_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE15_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE14_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE13_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE12_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE11_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE10_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE9_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE8_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE7_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE6_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE5_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE4_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE3_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE2_FIELD_NUMBER: _ClassVar[int]
    PARASET_BYTE1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    command: int
    set_num: int
    paraset_byte54: int
    paraset_byte53: int
    paraset_byte52: int
    paraset_byte51: int
    paraset_byte50: int
    paraset_byte49: int
    paraset_byte48: int
    paraset_byte47: int
    paraset_byte46: int
    paraset_byte45: int
    paraset_byte44: int
    paraset_byte43: int
    paraset_byte42: int
    paraset_byte41: int
    paraset_byte40: int
    paraset_byte39: int
    paraset_byte38: int
    paraset_byte37: int
    paraset_byte36: int
    paraset_byte35: int
    paraset_byte34: int
    paraset_byte33: int
    paraset_byte32: int
    paraset_byte31: int
    paraset_byte30: int
    paraset_byte29: int
    paraset_byte28: int
    paraset_byte27: int
    paraset_byte26: int
    paraset_byte25: int
    paraset_byte24: int
    paraset_byte23: int
    paraset_byte22: int
    paraset_byte21: int
    paraset_byte20: int
    paraset_byte19: int
    paraset_byte18: int
    paraset_byte17: int
    paraset_byte16: int
    paraset_byte15: int
    paraset_byte14: int
    paraset_byte13: int
    paraset_byte12: int
    paraset_byte11: int
    paraset_byte10: int
    paraset_byte9: int
    paraset_byte8: int
    paraset_byte7: int
    paraset_byte6: int
    paraset_byte5: int
    paraset_byte4: int
    paraset_byte3: int
    paraset_byte2: int
    paraset_byte1: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., command: _Optional[int] = ..., set_num: _Optional[int] = ..., paraset_byte54: _Optional[int] = ..., paraset_byte53: _Optional[int] = ..., paraset_byte52: _Optional[int] = ..., paraset_byte51: _Optional[int] = ..., paraset_byte50: _Optional[int] = ..., paraset_byte49: _Optional[int] = ..., paraset_byte48: _Optional[int] = ..., paraset_byte47: _Optional[int] = ..., paraset_byte46: _Optional[int] = ..., paraset_byte45: _Optional[int] = ..., paraset_byte44: _Optional[int] = ..., paraset_byte43: _Optional[int] = ..., paraset_byte42: _Optional[int] = ..., paraset_byte41: _Optional[int] = ..., paraset_byte40: _Optional[int] = ..., paraset_byte39: _Optional[int] = ..., paraset_byte38: _Optional[int] = ..., paraset_byte37: _Optional[int] = ..., paraset_byte36: _Optional[int] = ..., paraset_byte35: _Optional[int] = ..., paraset_byte34: _Optional[int] = ..., paraset_byte33: _Optional[int] = ..., paraset_byte32: _Optional[int] = ..., paraset_byte31: _Optional[int] = ..., paraset_byte30: _Optional[int] = ..., paraset_byte29: _Optional[int] = ..., paraset_byte28: _Optional[int] = ..., paraset_byte27: _Optional[int] = ..., paraset_byte26: _Optional[int] = ..., paraset_byte25: _Optional[int] = ..., paraset_byte24: _Optional[int] = ..., paraset_byte23: _Optional[int] = ..., paraset_byte22: _Optional[int] = ..., paraset_byte21: _Optional[int] = ..., paraset_byte20: _Optional[int] = ..., paraset_byte19: _Optional[int] = ..., paraset_byte18: _Optional[int] = ..., paraset_byte17: _Optional[int] = ..., paraset_byte16: _Optional[int] = ..., paraset_byte15: _Optional[int] = ..., paraset_byte14: _Optional[int] = ..., paraset_byte13: _Optional[int] = ..., paraset_byte12: _Optional[int] = ..., paraset_byte11: _Optional[int] = ..., paraset_byte10: _Optional[int] = ..., paraset_byte9: _Optional[int] = ..., paraset_byte8: _Optional[int] = ..., paraset_byte7: _Optional[int] = ..., paraset_byte6: _Optional[int] = ..., paraset_byte5: _Optional[int] = ..., paraset_byte4: _Optional[int] = ..., paraset_byte3: _Optional[int] = ..., paraset_byte2: _Optional[int] = ..., paraset_byte1: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetContaminationResultSrvRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetContaminationResultSrvResponse(_message.Message):
    __slots__ = ("warning", "error", "success")
    WARNING_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    warning: int
    error: int
    success: bool
    def __init__(self, warning: _Optional[int] = ..., error: _Optional[int] = ..., success: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgStatusGeneral(_message.Message):
    __slots__ = ("header", "main_power", "imu_power", "gps_power", "settings", "temperature", "datalogger", "cpu")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAIN_POWER_FIELD_NUMBER: _ClassVar[int]
    IMU_POWER_FIELD_NUMBER: _ClassVar[int]
    GPS_POWER_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    DATALOGGER_FIELD_NUMBER: _ClassVar[int]
    CPU_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    main_power: bool
    imu_power: bool
    gps_power: bool
    settings: bool
    temperature: bool
    datalogger: bool
    cpu: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., main_power: bool = ..., imu_power: bool = ..., gps_power: bool = ..., settings: bool = ..., temperature: bool = ..., datalogger: bool = ..., cpu: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_obstacle_msgs/msg/bounding_box3_d.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_vector3__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/rmf_obstacle_msgs/msg/bounding_box3_d.proto\x12\x32make87_messages_ros2.rolling.rmf_obstacle_msgs.msg\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\x1a<make87_messages_ros2/rolling/geometry_msgs/msg/vector3.proto\"\x9c\x01\n\rBoundingBox3D\x12\x44\n\x06\x63\x65nter\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x45\n\x04size\x18\x02 \x01(\x0b\x32\x37.make87_messages_ros2.rolling.geometry_msgs.msg.Vector3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_obstacle_msgs.msg.bounding_box3_d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOUNDINGBOX3D']._serialized_start=250
  _globals['_BOUNDINGBOX3D']._serialized_end=406
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import string_pb2 as _string_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParameterFloat64(_message.Message):
    __slots__ = ("name", "data")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    name: _string_pb2.String
    data: float
    def __init__(self, name: _Optional[_Union[_string_pb2.String, _Mapping]] = ..., data: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavHPPosECEF(_message.Message):
    __slots__ = ("header", "ros2_header", "version", "itow", "ecef_x", "ecef_y", "ecef_z", "ecef_x_hp", "ecef_y_hp", "ecef_z_hp", "invalid_ecef_x", "invalid_ecef_y", "invalid_ecef_z", "invalid_ecef_x_hp", "invalid_ecef_y_hp", "invalid_ecef_z_hp", "p_acc")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_FIELD_NUMBER: _ClassVar[int]
    ECEF_X_HP_FIELD_NUMBER: _ClassVar[int]
    ECEF_Y_HP_FIELD_NUMBER: _ClassVar[int]
    ECEF_Z_HP_FIELD_NUMBER: _ClassVar[int]
    INVALID_ECEF_X_FIELD_NUMBER: _ClassVar[int]
    INVALID_ECEF_Y_FIELD_NUMBER: _ClassVar[int]
    INVALID_ECEF_Z_FIELD_NUMBER: _ClassVar[int]
    INVALID_ECEF_X_HP_FIELD_NUMBER: _ClassVar[int]
    INVALID_ECEF_Y_HP_FIELD_NUMBER: _ClassVar[int]
    INVALID_ECEF_Z_HP_FIELD_NUMBER: _ClassVar[int]
    P_ACC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    version: int
    itow: int
    ecef_x: int
    ecef_y: int
    ecef_z: int
    ecef_x_hp: int
    ecef_y_hp: int
    ecef_z_hp: int
    invalid_ecef_x: bool
    invalid_ecef_y: bool
    invalid_ecef_z: bool
    invalid_ecef_x_hp: bool
    invalid_ecef_y_hp: bool
    invalid_ecef_z_hp: bool
    p_acc: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., version: _Optional[int] = ..., itow: _Optional[int] = ..., ecef_x: _Optional[int] = ..., ecef_y: _Optional[int] = ..., ecef_z: _Optional[int] = ..., ecef_x_hp: _Optional[int] = ..., ecef_y_hp: _Optional[int] = ..., ecef_z_hp: _Optional[int] = ..., invalid_ecef_x: bool = ..., invalid_ecef_y: bool = ..., invalid_ecef_z: bool = ..., invalid_ecef_x_hp: bool = ..., invalid_ecef_y_hp: bool = ..., invalid_ecef_z_hp: bool = ..., p_acc: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScenarioStatus(_message.Message):
    __slots__ = ("header", "system_time", "ros_time", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_TIME_FIELD_NUMBER: _ClassVar[int]
    ROS_TIME_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    system_time: _time_pb2.Time
    ros_time: _time_pb2.Time
    data: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., system_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., ros_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., data: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Velocity(_message.Message):
    __slots__ = ("header", "velocity", "variance")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    VARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    velocity: float
    variance: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., velocity: _Optional[float] = ..., variance: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DriverCommands(_message.Message):
    __slots__ = ("msg_counter", "engage", "disengage", "speed_up", "slow_down", "further", "closer", "right_turn", "left_turn")
    MSG_COUNTER_FIELD_NUMBER: _ClassVar[int]
    ENGAGE_FIELD_NUMBER: _ClassVar[int]
    DISENGAGE_FIELD_NUMBER: _ClassVar[int]
    SPEED_UP_FIELD_NUMBER: _ClassVar[int]
    SLOW_DOWN_FIELD_NUMBER: _ClassVar[int]
    FURTHER_FIELD_NUMBER: _ClassVar[int]
    CLOSER_FIELD_NUMBER: _ClassVar[int]
    RIGHT_TURN_FIELD_NUMBER: _ClassVar[int]
    LEFT_TURN_FIELD_NUMBER: _ClassVar[int]
    msg_counter: int
    engage: int
    disengage: int
    speed_up: int
    slow_down: int
    further: int
    closer: int
    right_turn: int
    left_turn: int
    def __init__(self, msg_counter: _Optional[int] = ..., engage: _Optional[int] = ..., disengage: _Optional[int] = ..., speed_up: _Optional[int] = ..., slow_down: _Optional[int] = ..., further: _Optional[int] = ..., closer: _Optional[int] = ..., right_turn: _Optional[int] = ..., left_turn: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TestArrayRequestRequest(_message.Message):
    __slots__ = ("int_values",)
    INT_VALUES_FIELD_NUMBER: _ClassVar[int]
    int_values: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, int_values: _Optional[_Iterable[int]] = ...) -> None: ...

class TestArrayRequestResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import box_pb2 as _box_pb2
from make87_messages_ros2.rolling.rc_reason_msgs.msg import rectangle_pb2 as _rectangle_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LoadCarrier(_message.Message):
    __slots__ = ("id", "type", "outer_dimensions", "inner_dimensions", "rim_thickness", "rim_step_height", "rim_ledge", "height_open_side", "pose", "overfilled")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    OUTER_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    INNER_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    RIM_THICKNESS_FIELD_NUMBER: _ClassVar[int]
    RIM_STEP_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    RIM_LEDGE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_OPEN_SIDE_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    OVERFILLED_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    outer_dimensions: _box_pb2.Box
    inner_dimensions: _box_pb2.Box
    rim_thickness: _rectangle_pb2.Rectangle
    rim_step_height: float
    rim_ledge: _rectangle_pb2.Rectangle
    height_open_side: float
    pose: _pose_stamped_pb2.PoseStamped
    overfilled: bool
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., outer_dimensions: _Optional[_Union[_box_pb2.Box, _Mapping]] = ..., inner_dimensions: _Optional[_Union[_box_pb2.Box, _Mapping]] = ..., rim_thickness: _Optional[_Union[_rectangle_pb2.Rectangle, _Mapping]] = ..., rim_step_height: _Optional[float] = ..., rim_ledge: _Optional[_Union[_rectangle_pb2.Rectangle, _Mapping]] = ..., height_open_side: _Optional[float] = ..., pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., overfilled: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VehicleStateData(_message.Message):
    __slots__ = ("header", "ros2_header", "blinker_state", "headlight_state", "wiper_state", "current_gear", "vehicle_mode", "hand_brake_active", "horn_active", "autonomous_mode_active")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    BLINKER_STATE_FIELD_NUMBER: _ClassVar[int]
    HEADLIGHT_STATE_FIELD_NUMBER: _ClassVar[int]
    WIPER_STATE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_GEAR_FIELD_NUMBER: _ClassVar[int]
    VEHICLE_MODE_FIELD_NUMBER: _ClassVar[int]
    HAND_BRAKE_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    HORN_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    AUTONOMOUS_MODE_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    blinker_state: int
    headlight_state: int
    wiper_state: int
    current_gear: int
    vehicle_mode: int
    hand_brake_active: bool
    horn_active: bool
    autonomous_mode_active: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., blinker_state: _Optional[int] = ..., headlight_state: _Optional[int] = ..., wiper_state: _Optional[int] = ..., current_gear: _Optional[int] = ..., vehicle_mode: _Optional[int] = ..., hand_brake_active: bool = ..., horn_active: bool = ..., autonomous_mode_active: bool = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmapEntry(_message.Message):
    __slots__ = ("trajectory_id", "submap_index", "submap_version", "pose", "is_frozen")
    TRAJECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMAP_INDEX_FIELD_NUMBER: _ClassVar[int]
    SUBMAP_VERSION_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    IS_FROZEN_FIELD_NUMBER: _ClassVar[int]
    trajectory_id: int
    submap_index: int
    submap_version: int
    pose: _pose_pb2.Pose
    is_frozen: bool
    def __init__(self, trajectory_id: _Optional[int] = ..., submap_index: _Optional[int] = ..., submap_version: _Optional[int] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., is_frozen: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gpgst(_message.Message):
    __slots__ = ("header", "ros2_header", "message_id", "utc_seconds", "rms", "semi_major_dev", "semi_minor_dev", "orientation", "lat_dev", "lon_dev", "alt_dev")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    UTC_SECONDS_FIELD_NUMBER: _ClassVar[int]
    RMS_FIELD_NUMBER: _ClassVar[int]
    SEMI_MAJOR_DEV_FIELD_NUMBER: _ClassVar[int]
    SEMI_MINOR_DEV_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    LAT_DEV_FIELD_NUMBER: _ClassVar[int]
    LON_DEV_FIELD_NUMBER: _ClassVar[int]
    ALT_DEV_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    message_id: str
    utc_seconds: float
    rms: float
    semi_major_dev: float
    semi_minor_dev: float
    orientation: float
    lat_dev: float
    lon_dev: float
    alt_dev: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., utc_seconds: _Optional[float] = ..., rms: _Optional[float] = ..., semi_major_dev: _Optional[float] = ..., semi_minor_dev: _Optional[float] = ..., orientation: _Optional[float] = ..., lat_dev: _Optional[float] = ..., lon_dev: _Optional[float] = ..., alt_dev: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PlayTuneV2(_message.Message):
    __slots__ = ("format", "tune")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    TUNE_FIELD_NUMBER: _ClassVar[int]
    format: int
    tune: str
    def __init__(self, format: _Optional[int] = ..., tune: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FourWheelSteering(_message.Message):
    __slots__ = ("header", "front_steering_angle", "rear_steering_angle", "front_steering_angle_velocity", "rear_steering_angle_velocity", "speed", "acceleration", "jerk")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FRONT_STEERING_ANGLE_FIELD_NUMBER: _ClassVar[int]
    REAR_STEERING_ANGLE_FIELD_NUMBER: _ClassVar[int]
    FRONT_STEERING_ANGLE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    REAR_STEERING_ANGLE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    JERK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    front_steering_angle: float
    rear_steering_angle: float
    front_steering_angle_velocity: float
    rear_steering_angle_velocity: float
    speed: float
    acceleration: float
    jerk: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., front_steering_angle: _Optional[float] = ..., rear_steering_angle: _Optional[float] = ..., front_steering_angle_velocity: _Optional[float] = ..., rear_steering_angle_velocity: _Optional[float] = ..., speed: _Optional[float] = ..., acceleration: _Optional[float] = ..., jerk: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_stamped_pb2 as _vector3_stamped_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalControl(_message.Message):
    __slots__ = ("header", "control_mode", "target")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONTROL_MODE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    control_mode: int
    target: _vector3_stamped_pb2.Vector3Stamped
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., control_mode: _Optional[int] = ..., target: _Optional[_Union[_vector3_stamped_pb2.Vector3Stamped, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/webots_ros2_msgs/msg/urdf_robot.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/webots_ros2_msgs/msg/urdf_robot.proto\x12\x31make87_messages_ros2.rolling.webots_ros2_msgs.msg\"\xc5\x01\n\tUrdfRobot\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\turdf_path\x18\x02 \x01(\t\x12\x19\n\x11robot_description\x18\x03 \x01(\t\x12\x1c\n\x14relative_path_prefix\x18\x04 \x01(\t\x12\x13\n\x0btranslation\x18\x05 \x01(\t\x12\x10\n\x08rotation\x18\x06 \x01(\t\x12\x0e\n\x06normal\x18\x07 \x01(\x08\x12\x15\n\rbox_collision\x18\x08 \x01(\x08\x12\x10\n\x08init_pos\x18\t \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.webots_ros2_msgs.msg.urdf_robot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_URDFROBOT']._serialized_start=122
  _globals['_URDFROBOT']._serialized_end=319
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.diagnostic_msgs.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import activity_item_pb2 as _activity_item_pb2
from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import behaviour_pb2 as _behaviour_pb2
from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import statistics_pb2 as _statistics_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviourTree(_message.Message):
    __slots__ = ("behaviours", "changed", "blackboard_on_visited_path", "blackboard_activity", "statistics")
    BEHAVIOURS_FIELD_NUMBER: _ClassVar[int]
    CHANGED_FIELD_NUMBER: _ClassVar[int]
    BLACKBOARD_ON_VISITED_PATH_FIELD_NUMBER: _ClassVar[int]
    BLACKBOARD_ACTIVITY_FIELD_NUMBER: _ClassVar[int]
    STATISTICS_FIELD_NUMBER: _ClassVar[int]
    behaviours: _containers.RepeatedCompositeFieldContainer[_behaviour_pb2.Behaviour]
    changed: bool
    blackboard_on_visited_path: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    blackboard_activity: _containers.RepeatedCompositeFieldContainer[_activity_item_pb2.ActivityItem]
    statistics: _statistics_pb2.Statistics
    def __init__(self, behaviours: _Optional[_Iterable[_Union[_behaviour_pb2.Behaviour, _Mapping]]] = ..., changed: bool = ..., blackboard_on_visited_path: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ..., blackboard_activity: _Optional[_Iterable[_Union[_activity_item_pb2.ActivityItem, _Mapping]]] = ..., statistics: _Optional[_Union[_statistics_pb2.Statistics, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.graph_msgs.msg import edges_pb2 as _edges_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GeometryGraph(_message.Message):
    __slots__ = ("header", "ros2_header", "nodes", "edges")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    EDGES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    nodes: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    edges: _containers.RepeatedCompositeFieldContainer[_edges_pb2.Edges]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., nodes: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., edges: _Optional[_Iterable[_Union[_edges_pb2.Edges, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/kobuki_ros_interfaces/msg/button_event.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/kobuki_ros_interfaces/msg/button_event.proto\x12\x36make87_messages_ros2.rolling.kobuki_ros_interfaces.msg\",\n\x0b\x42uttonEvent\x12\x0e\n\x06\x62utton\x18\x01 \x01(\r\x12\r\n\x05state\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.kobuki_ros_interfaces.msg.button_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BUTTONEVENT']._serialized_start=133
  _globals['_BUTTONEVENT']._serialized_end=177
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import beam_pb2 as _beam_pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import hinge_joint_vel_pb2 as _hinge_joint_vel_pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import say_pb2 as _say_pb2
from make87_messages_ros2.rolling.rcss3d_agent_msgs.msg import universal_joint_vel_pb2 as _universal_joint_vel_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Effector(_message.Message):
    __slots__ = ("hinge_joint_vels", "universal_joint_vels", "beams", "says")
    HINGE_JOINT_VELS_FIELD_NUMBER: _ClassVar[int]
    UNIVERSAL_JOINT_VELS_FIELD_NUMBER: _ClassVar[int]
    BEAMS_FIELD_NUMBER: _ClassVar[int]
    SAYS_FIELD_NUMBER: _ClassVar[int]
    hinge_joint_vels: _containers.RepeatedCompositeFieldContainer[_hinge_joint_vel_pb2.HingeJointVel]
    universal_joint_vels: _containers.RepeatedCompositeFieldContainer[_universal_joint_vel_pb2.UniversalJointVel]
    beams: _containers.RepeatedCompositeFieldContainer[_beam_pb2.Beam]
    says: _containers.RepeatedCompositeFieldContainer[_say_pb2.Say]
    def __init__(self, hinge_joint_vels: _Optional[_Iterable[_Union[_hinge_joint_vel_pb2.HingeJointVel, _Mapping]]] = ..., universal_joint_vels: _Optional[_Iterable[_Union[_universal_joint_vel_pb2.UniversalJointVel, _Mapping]]] = ..., beams: _Optional[_Iterable[_Union[_beam_pb2.Beam, _Mapping]]] = ..., says: _Optional[_Iterable[_Union[_say_pb2.Say, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.jazzy.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GoalInfo(_message.Message):
    __slots__ = ("goal_id", "stamp")
    GOAL_ID_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    goal_id: _uuid_pb2.UUID
    stamp: _time_pb2.Time
    def __init__(self, goal_id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import transform_stamped_pb2 as _transform_stamped_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TFMessage(_message.Message):
    __slots__ = ("transforms",)
    TRANSFORMS_FIELD_NUMBER: _ClassVar[int]
    transforms: _containers.RepeatedCompositeFieldContainer[_transform_stamped_pb2.TransformStamped]
    def __init__(self, transforms: _Optional[_Iterable[_Union[_transform_stamped_pb2.TransformStamped, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResponse(_message.Message):
    __slots__ = ("type", "json_msg", "request_id")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    JSON_MSG_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    type: int
    json_msg: str
    request_id: str
    def __init__(self, type: _Optional[int] = ..., json_msg: _Optional[str] = ..., request_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/esf_ins.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/esf_ins.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xac\x01\n\x06\x45sfINS\x12\x11\n\tbitfield0\x18\x01 \x01(\r\x12\x11\n\treserved1\x18\x02 \x03(\r\x12\r\n\x05i_tow\x18\x03 \x01(\r\x12\x12\n\nx_ang_rate\x18\x04 \x01(\x05\x12\x12\n\ny_ang_rate\x18\x05 \x01(\x05\x12\x12\n\nz_ang_rate\x18\x06 \x01(\x05\x12\x0f\n\x07x_accel\x18\x07 \x01(\x05\x12\x0f\n\x07y_accel\x18\x08 \x01(\x05\x12\x0f\n\x07z_accel\x18\t \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.esf_ins_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESFINS']._serialized_start=107
  _globals['_ESFINS']._serialized_end=279
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Loop(_message.Message):
    __slots__ = ("header", "task_id", "robot_type", "num_loops", "start_name", "finish_name")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    ROBOT_TYPE_FIELD_NUMBER: _ClassVar[int]
    NUM_LOOPS_FIELD_NUMBER: _ClassVar[int]
    START_NAME_FIELD_NUMBER: _ClassVar[int]
    FINISH_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    task_id: str
    robot_type: str
    num_loops: int
    start_name: str
    finish_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., task_id: _Optional[str] = ..., robot_type: _Optional[str] = ..., num_loops: _Optional[int] = ..., start_name: _Optional[str] = ..., finish_name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/swri_roscpp/msg/test_topic_service_response.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.marti_common_msgs.msg import service_header_pb2 as make87__messages__ros2_dot_humble_dot_marti__common__msgs_dot_msg_dot_service__header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/swri_roscpp/msg/test_topic_service_response.proto\x12+make87_messages_ros2.humble.swri_roscpp.msg\x1a!make87_messages/core/header.proto\x1a\x46make87_messages_ros2/humble/marti_common_msgs/msg/service_header.proto\"\xb6\x01\n\x18TestTopicServiceResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12T\n\nsrv_header\x18\x02 \x01(\x0b\x32@.make87_messages_ros2.humble.marti_common_msgs.msg.ServiceHeader\x12\x16\n\x0eresponse_value\x18\x03 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.swri_roscpp.msg.test_topic_service_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTTOPICSERVICERESPONSE']._serialized_start=234
  _globals['_TESTTOPICSERVICERESPONSE']._serialized_end=416
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.trajectory_msgs.msg import joint_trajectory_point_pb2 as _joint_trajectory_point_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JointTrajectory(_message.Message):
    __slots__ = ("header", "ros2_header", "joint_names", "points")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    JOINT_NAMES_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    joint_names: _containers.RepeatedScalarFieldContainer[str]
    points: _containers.RepeatedCompositeFieldContainer[_joint_trajectory_point_pb2.JointTrajectoryPoint]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., joint_names: _Optional[_Iterable[str]] = ..., points: _Optional[_Iterable[_Union[_joint_trajectory_point_pb2.JointTrajectoryPoint, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_extended_solution_status_pb2 as _novatel_extended_solution_status_pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_message_header_pb2 as _novatel_message_header_pb2
from make87_messages_ros2.rolling.novatel_gps_msgs.msg import novatel_signal_mask_pb2 as _novatel_signal_mask_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NovatelPosition(_message.Message):
    __slots__ = ("header", "novatel_msg_header", "solution_status", "position_type", "lat", "lon", "height", "undulation", "datum_id", "lat_sigma", "lon_sigma", "height_sigma", "base_station_id", "diff_age", "solution_age", "num_satellites_tracked", "num_satellites_used_in_solution", "num_gps_and_glonass_l1_used_in_solution", "num_gps_and_glonass_l1_and_l2_used_in_solution", "extended_solution_status", "signal_mask")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NOVATEL_MSG_HEADER_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    POSITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    LAT_FIELD_NUMBER: _ClassVar[int]
    LON_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    UNDULATION_FIELD_NUMBER: _ClassVar[int]
    DATUM_ID_FIELD_NUMBER: _ClassVar[int]
    LAT_SIGMA_FIELD_NUMBER: _ClassVar[int]
    LON_SIGMA_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_SIGMA_FIELD_NUMBER: _ClassVar[int]
    BASE_STATION_ID_FIELD_NUMBER: _ClassVar[int]
    DIFF_AGE_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_AGE_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_TRACKED_FIELD_NUMBER: _ClassVar[int]
    NUM_SATELLITES_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    NUM_GPS_AND_GLONASS_L1_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    NUM_GPS_AND_GLONASS_L1_AND_L2_USED_IN_SOLUTION_FIELD_NUMBER: _ClassVar[int]
    EXTENDED_SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_MASK_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    novatel_msg_header: _novatel_message_header_pb2.NovatelMessageHeader
    solution_status: str
    position_type: str
    lat: float
    lon: float
    height: float
    undulation: float
    datum_id: str
    lat_sigma: float
    lon_sigma: float
    height_sigma: float
    base_station_id: str
    diff_age: float
    solution_age: float
    num_satellites_tracked: int
    num_satellites_used_in_solution: int
    num_gps_and_glonass_l1_used_in_solution: int
    num_gps_and_glonass_l1_and_l2_used_in_solution: int
    extended_solution_status: _novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus
    signal_mask: _novatel_signal_mask_pb2.NovatelSignalMask
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., novatel_msg_header: _Optional[_Union[_novatel_message_header_pb2.NovatelMessageHeader, _Mapping]] = ..., solution_status: _Optional[str] = ..., position_type: _Optional[str] = ..., lat: _Optional[float] = ..., lon: _Optional[float] = ..., height: _Optional[float] = ..., undulation: _Optional[float] = ..., datum_id: _Optional[str] = ..., lat_sigma: _Optional[float] = ..., lon_sigma: _Optional[float] = ..., height_sigma: _Optional[float] = ..., base_station_id: _Optional[str] = ..., diff_age: _Optional[float] = ..., solution_age: _Optional[float] = ..., num_satellites_tracked: _Optional[int] = ..., num_satellites_used_in_solution: _Optional[int] = ..., num_gps_and_glonass_l1_used_in_solution: _Optional[int] = ..., num_gps_and_glonass_l1_and_l2_used_in_solution: _Optional[int] = ..., extended_solution_status: _Optional[_Union[_novatel_extended_solution_status_pb2.NovatelExtendedSolutionStatus, _Mapping]] = ..., signal_mask: _Optional[_Union[_novatel_signal_mask_pb2.NovatelSignalMask, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ibeo_msgs/msg/object_data2270.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.jazzy.ibeo_msgs.msg import object2270_pb2 as make87__messages__ros2_dot_jazzy_dot_ibeo__msgs_dot_msg_dot_object2270__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/ibeo_msgs/msg/object_data2270.proto\x12(make87_messages_ros2.jazzy.ibeo_msgs.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a?make87_messages_ros2/jazzy/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x39make87_messages_ros2/jazzy/ibeo_msgs/msg/object2270.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf9\x02\n\x0eObjectData2270\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12M\n\x0bibeo_header\x18\x02 \x01(\x0b\x32\x38.make87_messages_ros2.jazzy.ibeo_msgs.msg.IbeoDataHeader\x12U\n\x14start_scan_timestamp\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x1a\n\x12object_list_number\x18\x04 \x01(\r\x12\x19\n\x11number_of_objects\x18\x05 \x01(\r\x12I\n\x0bobject_list\x18\x06 \x03(\x0b\x32\x34.make87_messages_ros2.jazzy.ibeo_msgs.msg.Object2270b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ibeo_msgs.msg.object_data2270_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OBJECTDATA2270']._serialized_start=349
  _globals['_OBJECTDATA2270']._serialized_end=726
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.rcl_interfaces.msg import parameter_value_pb2 as _parameter_value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetParametersRequest(_message.Message):
    __slots__ = ("names",)
    NAMES_FIELD_NUMBER: _ClassVar[int]
    names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, names: _Optional[_Iterable[str]] = ...) -> None: ...

class GetParametersResponse(_message.Message):
    __slots__ = ("values",)
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedCompositeFieldContainer[_parameter_value_pb2.ParameterValue]
    def __init__(self, values: _Optional[_Iterable[_Union[_parameter_value_pb2.ParameterValue, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import twist_pb2 as _twist_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VelocityStamped(_message.Message):
    __slots__ = ("header", "body_frame_id", "reference_frame_id", "velocity")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BODY_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FRAME_ID_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    body_frame_id: str
    reference_frame_id: str
    velocity: _twist_pb2.Twist
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., body_frame_id: _Optional[str] = ..., reference_frame_id: _Optional[str] = ..., velocity: _Optional[_Union[_twist_pb2.Twist, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.actuator_msgs.msg import actuators_angular_position_pb2 as _actuators_angular_position_pb2
from make87_messages_ros2.jazzy.actuator_msgs.msg import actuators_linear_position_pb2 as _actuators_linear_position_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActuatorsPosition(_message.Message):
    __slots__ = ("header", "angular", "linear")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_FIELD_NUMBER: _ClassVar[int]
    LINEAR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    angular: _actuators_angular_position_pb2.ActuatorsAngularPosition
    linear: _actuators_linear_position_pb2.ActuatorsLinearPosition
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., angular: _Optional[_Union[_actuators_angular_position_pb2.ActuatorsAngularPosition, _Mapping]] = ..., linear: _Optional[_Union[_actuators_linear_position_pb2.ActuatorsLinearPosition, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TestTimeArray(_message.Message):
    __slots__ = ("times",)
    TIMES_FIELD_NUMBER: _ClassVar[int]
    times: _containers.RepeatedCompositeFieldContainer[_time_pb2.Time]
    def __init__(self, times: _Optional[_Iterable[_Union[_time_pb2.Time, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marker_msgs/msg/fiducial.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_point__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/marker_msgs/msg/fiducial.proto\x12,make87_messages_ros2.rolling.marker_msgs.msg\x1a:make87_messages_ros2/rolling/geometry_msgs/msg/point.proto\"\xca\x01\n\x08\x46iducial\x12\x0b\n\x03ids\x18\x01 \x03(\x05\x12\x16\n\x0eids_confidence\x18\x02 \x03(\x01\x12L\n\robject_points\x18\x03 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Point\x12K\n\x0cimage_points\x18\x04 \x03(\x0b\x32\x35.make87_messages_ros2.rolling.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marker_msgs.msg.fiducial_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FIDUCIAL']._serialized_start=170
  _globals['_FIDUCIAL']._serialized_end=372
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.marti_nav_msgs.msg import path_point_pb2 as _path_point_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Path(_message.Message):
    __slots__ = ("header", "points", "in_reverse")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    IN_REVERSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    points: _containers.RepeatedCompositeFieldContainer[_path_point_pb2.PathPoint]
    in_reverse: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., points: _Optional[_Iterable[_Union[_path_point_pb2.PathPoint, _Mapping]]] = ..., in_reverse: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/ublox_msgs/msg/esf_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.ublox_msgs.msg import esf_status_sens_pb2 as make87__messages__ros2_dot_humble_dot_ublox__msgs_dot_msg_dot_esf__status__sens__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/ublox_msgs/msg/esf_status.proto\x12*make87_messages_ros2.humble.ublox_msgs.msg\x1a!make87_messages/core/header.proto\x1a@make87_messages_ros2/humble/ublox_msgs/msg/esf_status_sens.proto\"\xef\x01\n\tEsfSTATUS\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05i_tow\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x11\n\treserved1\x18\x04 \x03(\r\x12\x13\n\x0b\x66usion_mode\x18\x05 \x01(\r\x12\x11\n\treserved2\x18\x06 \x03(\r\x12\x10\n\x08num_sens\x18\x07 \x01(\r\x12G\n\x04sens\x18\x08 \x03(\x0b\x32\x39.make87_messages_ros2.humble.ublox_msgs.msg.EsfSTATUSSensb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.ublox_msgs.msg.esf_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ESFSTATUS']._serialized_start=209
  _globals['_ESFSTATUS']._serialized_end=448
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CommandIntRequest(_message.Message):
    __slots__ = ("broadcast", "frame", "command", "current", "autocontinue", "param1", "param2", "param3", "param4", "x", "y", "z")
    BROADCAST_FIELD_NUMBER: _ClassVar[int]
    FRAME_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    CURRENT_FIELD_NUMBER: _ClassVar[int]
    AUTOCONTINUE_FIELD_NUMBER: _ClassVar[int]
    PARAM1_FIELD_NUMBER: _ClassVar[int]
    PARAM2_FIELD_NUMBER: _ClassVar[int]
    PARAM3_FIELD_NUMBER: _ClassVar[int]
    PARAM4_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    Z_FIELD_NUMBER: _ClassVar[int]
    broadcast: bool
    frame: int
    command: int
    current: int
    autocontinue: int
    param1: float
    param2: float
    param3: float
    param4: float
    x: int
    y: int
    z: float
    def __init__(self, broadcast: bool = ..., frame: _Optional[int] = ..., command: _Optional[int] = ..., current: _Optional[int] = ..., autocontinue: _Optional[int] = ..., param1: _Optional[float] = ..., param2: _Optional[float] = ..., param3: _Optional[float] = ..., param4: _Optional[float] = ..., x: _Optional[int] = ..., y: _Optional[int] = ..., z: _Optional[float] = ...) -> None: ...

class CommandIntResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UnregisterParticipantRequest(_message.Message):
    __slots__ = ("participant_id",)
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    participant_id: int
    def __init__(self, participant_id: _Optional[int] = ...) -> None: ...

class UnregisterParticipantResponse(_message.Message):
    __slots__ = ("confirmation", "error")
    CONFIRMATION_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    confirmation: bool
    error: str
    def __init__(self, confirmation: bool = ..., error: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import wrench_pb2 as _wrench_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplyLinkWrenchRequest(_message.Message):
    __slots__ = ("header", "link_name", "reference_frame", "reference_point", "wrench", "start_time", "duration")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FRAME_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_FIELD_NUMBER: _ClassVar[int]
    WRENCH_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    link_name: str
    reference_frame: str
    reference_point: _point_pb2.Point
    wrench: _wrench_pb2.Wrench
    start_time: _time_pb2.Time
    duration: _duration_pb2.Duration
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., link_name: _Optional[str] = ..., reference_frame: _Optional[str] = ..., reference_point: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., wrench: _Optional[_Union[_wrench_pb2.Wrench, _Mapping]] = ..., start_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ApplyLinkWrenchResponse(_message.Message):
    __slots__ = ("header", "success", "status_message")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    status_message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MasterboardDataMsg(_message.Message):
    __slots__ = ("digital_input_bits", "digital_output_bits", "analog_input_range0", "analog_input_range1", "analog_input0", "analog_input1", "analog_output_domain0", "analog_output_domain1", "analog_output0", "analog_output1", "masterboard_temperature", "robot_voltage_48v", "robot_current", "master_io_current", "master_safety_state", "master_onoff_state")
    DIGITAL_INPUT_BITS_FIELD_NUMBER: _ClassVar[int]
    DIGITAL_OUTPUT_BITS_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT_RANGE0_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT_RANGE1_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT0_FIELD_NUMBER: _ClassVar[int]
    ANALOG_INPUT1_FIELD_NUMBER: _ClassVar[int]
    ANALOG_OUTPUT_DOMAIN0_FIELD_NUMBER: _ClassVar[int]
    ANALOG_OUTPUT_DOMAIN1_FIELD_NUMBER: _ClassVar[int]
    ANALOG_OUTPUT0_FIELD_NUMBER: _ClassVar[int]
    ANALOG_OUTPUT1_FIELD_NUMBER: _ClassVar[int]
    MASTERBOARD_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    ROBOT_VOLTAGE_48V_FIELD_NUMBER: _ClassVar[int]
    ROBOT_CURRENT_FIELD_NUMBER: _ClassVar[int]
    MASTER_IO_CURRENT_FIELD_NUMBER: _ClassVar[int]
    MASTER_SAFETY_STATE_FIELD_NUMBER: _ClassVar[int]
    MASTER_ONOFF_STATE_FIELD_NUMBER: _ClassVar[int]
    digital_input_bits: int
    digital_output_bits: int
    analog_input_range0: int
    analog_input_range1: int
    analog_input0: float
    analog_input1: float
    analog_output_domain0: int
    analog_output_domain1: int
    analog_output0: float
    analog_output1: float
    masterboard_temperature: float
    robot_voltage_48v: float
    robot_current: float
    master_io_current: float
    master_safety_state: int
    master_onoff_state: int
    def __init__(self, digital_input_bits: _Optional[int] = ..., digital_output_bits: _Optional[int] = ..., analog_input_range0: _Optional[int] = ..., analog_input_range1: _Optional[int] = ..., analog_input0: _Optional[float] = ..., analog_input1: _Optional[float] = ..., analog_output_domain0: _Optional[int] = ..., analog_output_domain1: _Optional[int] = ..., analog_output0: _Optional[float] = ..., analog_output1: _Optional[float] = ..., masterboard_temperature: _Optional[float] = ..., robot_voltage_48v: _Optional[float] = ..., robot_current: _Optional[float] = ..., master_io_current: _Optional[float] = ..., master_safety_state: _Optional[int] = ..., master_onoff_state: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TopicInfo(_message.Message):
    __slots__ = ("header", "name", "resolved_name", "description", "group", "message_type", "advertised")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ADVERTISED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    name: str
    resolved_name: str
    description: str
    group: str
    message_type: str
    advertised: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., name: _Optional[str] = ..., resolved_name: _Optional[str] = ..., description: _Optional[str] = ..., group: _Optional[str] = ..., message_type: _Optional[str] = ..., advertised: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UlcReport(_message.Message):
    __slots__ = ("header", "cmd_type", "vel_ref", "vel_meas", "accel_ref", "accel_meas", "coast_decel", "ready", "enabled", "override_active", "override_latched", "preempted", "timeout", "bad_crc", "bad_rc")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CMD_TYPE_FIELD_NUMBER: _ClassVar[int]
    VEL_REF_FIELD_NUMBER: _ClassVar[int]
    VEL_MEAS_FIELD_NUMBER: _ClassVar[int]
    ACCEL_REF_FIELD_NUMBER: _ClassVar[int]
    ACCEL_MEAS_FIELD_NUMBER: _ClassVar[int]
    COAST_DECEL_FIELD_NUMBER: _ClassVar[int]
    READY_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_LATCHED_FIELD_NUMBER: _ClassVar[int]
    PREEMPTED_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    BAD_CRC_FIELD_NUMBER: _ClassVar[int]
    BAD_RC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    cmd_type: int
    vel_ref: float
    vel_meas: float
    accel_ref: float
    accel_meas: float
    coast_decel: bool
    ready: bool
    enabled: bool
    override_active: bool
    override_latched: bool
    preempted: bool
    timeout: bool
    bad_crc: bool
    bad_rc: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., cmd_type: _Optional[int] = ..., vel_ref: _Optional[float] = ..., vel_meas: _Optional[float] = ..., accel_ref: _Optional[float] = ..., accel_meas: _Optional[float] = ..., coast_decel: bool = ..., ready: bool = ..., enabled: bool = ..., override_active: bool = ..., override_latched: bool = ..., preempted: bool = ..., timeout: bool = ..., bad_crc: bool = ..., bad_rc: bool = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DebugValue(_message.Message):
    __slots__ = ("header", "ros2_header", "index", "array_id", "name", "value_float", "value_int", "data", "type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    ARRAY_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FLOAT_FIELD_NUMBER: _ClassVar[int]
    VALUE_INT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    index: int
    array_id: int
    name: str
    value_float: float
    value_int: int
    data: _containers.RepeatedScalarFieldContainer[float]
    type: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., index: _Optional[int] = ..., array_id: _Optional[int] = ..., name: _Optional[str] = ..., value_float: _Optional[float] = ..., value_int: _Optional[int] = ..., data: _Optional[_Iterable[float]] = ..., type: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.tuw_graph_msgs.msg import graph_pb2 as _graph_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetGraphRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetGraphResponse(_message.Message):
    __slots__ = ("graph",)
    GRAPH_FIELD_NUMBER: _ClassVar[int]
    graph: _graph_pb2.Graph
    def __init__(self, graph: _Optional[_Union[_graph_pb2.Graph, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FieldSetReadSrvRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class FieldSetReadSrvResponse(_message.Message):
    __slots__ = ("header", "field_set_selection_method", "active_field_set", "success")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FIELD_SET_SELECTION_METHOD_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_SET_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    field_set_selection_method: int
    active_field_set: int
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., field_set_selection_method: _Optional[int] = ..., active_field_set: _Optional[int] = ..., success: bool = ...) -> None: ...



from make87_messages_ros2.rolling.flexbe_msgs.msg import behavior_modification_pb2 as _behavior_modification_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BehaviorSelection(_message.Message):
    __slots__ = ("behavior_key", "behavior_id", "autonomy_level", "arg_keys", "arg_values", "input_keys", "input_values", "modifications")
    BEHAVIOR_KEY_FIELD_NUMBER: _ClassVar[int]
    BEHAVIOR_ID_FIELD_NUMBER: _ClassVar[int]
    AUTONOMY_LEVEL_FIELD_NUMBER: _ClassVar[int]
    ARG_KEYS_FIELD_NUMBER: _ClassVar[int]
    ARG_VALUES_FIELD_NUMBER: _ClassVar[int]
    INPUT_KEYS_FIELD_NUMBER: _ClassVar[int]
    INPUT_VALUES_FIELD_NUMBER: _ClassVar[int]
    MODIFICATIONS_FIELD_NUMBER: _ClassVar[int]
    behavior_key: int
    behavior_id: int
    autonomy_level: int
    arg_keys: _containers.RepeatedScalarFieldContainer[str]
    arg_values: _containers.RepeatedScalarFieldContainer[str]
    input_keys: _containers.RepeatedScalarFieldContainer[str]
    input_values: _containers.RepeatedScalarFieldContainer[str]
    modifications: _containers.RepeatedCompositeFieldContainer[_behavior_modification_pb2.BehaviorModification]
    def __init__(self, behavior_key: _Optional[int] = ..., behavior_id: _Optional[int] = ..., autonomy_level: _Optional[int] = ..., arg_keys: _Optional[_Iterable[str]] = ..., arg_values: _Optional[_Iterable[str]] = ..., input_keys: _Optional[_Iterable[str]] = ..., input_values: _Optional[_Iterable[str]] = ..., modifications: _Optional[_Iterable[_Union[_behavior_modification_pb2.BehaviorModification, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.jazzy.marine_acoustic_msgs.msg import detection_flag_pb2 as _detection_flag_pb2
from make87_messages_ros2.jazzy.marine_acoustic_msgs.msg import ping_info_pb2 as _ping_info_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SonarRanges(_message.Message):
    __slots__ = ("header", "ping_info", "flags", "transmit_delays", "intensities", "beam_unit_vec", "ranges")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PING_INFO_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    TRANSMIT_DELAYS_FIELD_NUMBER: _ClassVar[int]
    INTENSITIES_FIELD_NUMBER: _ClassVar[int]
    BEAM_UNIT_VEC_FIELD_NUMBER: _ClassVar[int]
    RANGES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ping_info: _ping_info_pb2.PingInfo
    flags: _containers.RepeatedCompositeFieldContainer[_detection_flag_pb2.DetectionFlag]
    transmit_delays: _containers.RepeatedScalarFieldContainer[float]
    intensities: _containers.RepeatedScalarFieldContainer[float]
    beam_unit_vec: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    ranges: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ping_info: _Optional[_Union[_ping_info_pb2.PingInfo, _Mapping]] = ..., flags: _Optional[_Iterable[_Union[_detection_flag_pb2.DetectionFlag, _Mapping]]] = ..., transmit_delays: _Optional[_Iterable[float]] = ..., intensities: _Optional[_Iterable[float]] = ..., beam_unit_vec: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., ranges: _Optional[_Iterable[float]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class TopicsAndRawTypesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TopicsAndRawTypesResponse(_message.Message):
    __slots__ = ("topics", "types", "typedefs_full_text")
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    TYPES_FIELD_NUMBER: _ClassVar[int]
    TYPEDEFS_FULL_TEXT_FIELD_NUMBER: _ClassVar[int]
    topics: _containers.RepeatedScalarFieldContainer[str]
    types: _containers.RepeatedScalarFieldContainer[str]
    typedefs_full_text: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, topics: _Optional[_Iterable[str]] = ..., types: _Optional[_Iterable[str]] = ..., typedefs_full_text: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrkStat(_message.Message):
    __slots__ = ("header", "pr_valid", "cp_valid", "half_cyc", "sub_half_cyc")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PR_VALID_FIELD_NUMBER: _ClassVar[int]
    CP_VALID_FIELD_NUMBER: _ClassVar[int]
    HALF_CYC_FIELD_NUMBER: _ClassVar[int]
    SUB_HALF_CYC_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pr_valid: bool
    cp_valid: bool
    half_cyc: bool
    sub_half_cyc: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pr_valid: bool = ..., cp_valid: bool = ..., half_cyc: bool = ..., sub_half_cyc: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import carr_soln_pb2 as _carr_soln_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import gps_fix_pb2 as _gps_fix_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import map_matching_pb2 as _map_matching_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import psm_status_pb2 as _psm_status_pb2
from make87_messages_ros2.jazzy.ublox_ubx_msgs.msg import spoof_det_pb2 as _spoof_det_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXNavStatus(_message.Message):
    __slots__ = ("header", "itow", "gps_fix", "gps_fix_ok", "diff_soln", "wkn_set", "tow_set", "diff_corr", "carr_soln_valid", "map_matching", "psm", "spoof_det", "carr_soln", "ttff", "msss")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    GPS_FIX_FIELD_NUMBER: _ClassVar[int]
    GPS_FIX_OK_FIELD_NUMBER: _ClassVar[int]
    DIFF_SOLN_FIELD_NUMBER: _ClassVar[int]
    WKN_SET_FIELD_NUMBER: _ClassVar[int]
    TOW_SET_FIELD_NUMBER: _ClassVar[int]
    DIFF_CORR_FIELD_NUMBER: _ClassVar[int]
    CARR_SOLN_VALID_FIELD_NUMBER: _ClassVar[int]
    MAP_MATCHING_FIELD_NUMBER: _ClassVar[int]
    PSM_FIELD_NUMBER: _ClassVar[int]
    SPOOF_DET_FIELD_NUMBER: _ClassVar[int]
    CARR_SOLN_FIELD_NUMBER: _ClassVar[int]
    TTFF_FIELD_NUMBER: _ClassVar[int]
    MSSS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    itow: int
    gps_fix: _gps_fix_pb2.GpsFix
    gps_fix_ok: bool
    diff_soln: bool
    wkn_set: bool
    tow_set: bool
    diff_corr: bool
    carr_soln_valid: bool
    map_matching: _map_matching_pb2.MapMatching
    psm: _psm_status_pb2.PSMStatus
    spoof_det: _spoof_det_pb2.SpoofDet
    carr_soln: _carr_soln_pb2.CarrSoln
    ttff: int
    msss: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., itow: _Optional[int] = ..., gps_fix: _Optional[_Union[_gps_fix_pb2.GpsFix, _Mapping]] = ..., gps_fix_ok: bool = ..., diff_soln: bool = ..., wkn_set: bool = ..., tow_set: bool = ..., diff_corr: bool = ..., carr_soln_valid: bool = ..., map_matching: _Optional[_Union[_map_matching_pb2.MapMatching, _Mapping]] = ..., psm: _Optional[_Union[_psm_status_pb2.PSMStatus, _Mapping]] = ..., spoof_det: _Optional[_Union[_spoof_det_pb2.SpoofDet, _Mapping]] = ..., carr_soln: _Optional[_Union[_carr_soln_pb2.CarrSoln, _Mapping]] = ..., ttff: _Optional[int] = ..., msss: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_interfaces/srv/warm_start.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/ublox_ubx_interfaces/srv/warm_start.proto\x12\x35make87_messages_ros2.rolling.ublox_ubx_interfaces.srv\"&\n\x10WarmStartRequest\x12\x12\n\nreset_type\x18\x01 \x01(\r\"\x13\n\x11WarmStartResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_interfaces.srv.warm_start_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_WARMSTARTREQUEST']._serialized_start=129
  _globals['_WARMSTARTREQUEST']._serialized_end=167
  _globals['_WARMSTARTRESPONSE']._serialized_start=169
  _globals['_WARMSTARTRESPONSE']._serialized_end=188
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Hear(_message.Message):
    __slots__ = ("header", "team", "time", "self", "direction", "message")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TEAM_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    SELF_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    team: str
    time: float
    self: bool
    direction: _containers.RepeatedScalarFieldContainer[float]
    message: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., team: _Optional[str] = ..., time: _Optional[float] = ..., self: bool = ..., direction: _Optional[_Iterable[float]] = ..., message: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/unitree_ros/msg/bms_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/unitree_ros/msg/bms_state.proto\x12+make87_messages_ros2.humble.unitree_ros.msg\x1a!make87_messages/core/header.proto\"\xd2\x01\n\x08\x42msState\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x11\n\tversion_h\x18\x02 \x01(\r\x12\x11\n\tversion_l\x18\x03 \x01(\r\x12\x12\n\nbms_status\x18\x04 \x01(\r\x12\x0b\n\x03soc\x18\x05 \x01(\r\x12\x0f\n\x07\x63urrent\x18\x06 \x01(\x05\x12\r\n\x05\x63ycle\x18\x07 \x01(\r\x12\x0e\n\x06\x62q_ntc\x18\x08 \x03(\x05\x12\x0f\n\x07mcu_ntc\x18\t \x03(\x05\x12\x10\n\x08\x63\x65ll_vol\x18\n \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.unitree_ros.msg.bms_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BMSSTATE']._serialized_start=144
  _globals['_BMSSTATE']._serialized_end=354
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mavros_msgs/msg/waypoint.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/mavros_msgs/msg/waypoint.proto\x12*make87_messages_ros2.jazzy.mavros_msgs.msg\"\xc2\x01\n\x08Waypoint\x12\r\n\x05\x66rame\x18\x01 \x01(\r\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\r\x12\x12\n\nis_current\x18\x03 \x01(\x08\x12\x14\n\x0c\x61utocontinue\x18\x04 \x01(\x08\x12\x0e\n\x06param1\x18\x05 \x01(\x02\x12\x0e\n\x06param2\x18\x06 \x01(\x02\x12\x0e\n\x06param3\x18\x07 \x01(\x02\x12\x0e\n\x06param4\x18\x08 \x01(\x02\x12\r\n\x05x_lat\x18\t \x01(\x01\x12\x0e\n\x06y_long\x18\n \x01(\x01\x12\r\n\x05z_alt\x18\x0b \x01(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mavros_msgs.msg.waypoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_WAYPOINT']._serialized_start=106
  _globals['_WAYPOINT']._serialized_end=300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/autoware_planning_msgs/msg/path.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.autoware_planning_msgs.msg import path_point_pb2 as make87__messages__ros2_dot_jazzy_dot_autoware__planning__msgs_dot_msg_dot_path__point__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import point_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_point__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/jazzy/autoware_planning_msgs/msg/path.proto\x12\x35make87_messages_ros2.jazzy.autoware_planning_msgs.msg\x1a\x46make87_messages_ros2/jazzy/autoware_planning_msgs/msg/path_point.proto\x1a\x38make87_messages_ros2/jazzy/geometry_msgs/msg/point.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xac\x02\n\x04Path\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12P\n\x06points\x18\x02 \x03(\x0b\x32@.make87_messages_ros2.jazzy.autoware_planning_msgs.msg.PathPoint\x12G\n\nleft_bound\x18\x03 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Point\x12H\n\x0bright_bound\x18\x04 \x03(\x0b\x32\x33.make87_messages_ros2.jazzy.geometry_msgs.msg.Pointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.autoware_planning_msgs.msg.path_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PATH']._serialized_start=308
  _globals['_PATH']._serialized_end=608
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Gpzda(_message.Message):
    __slots__ = ("header", "message_id", "utc_seconds", "day", "month", "year", "hour_offset_gmt", "minute_offset_gmt")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    UTC_SECONDS_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    HOUR_OFFSET_GMT_FIELD_NUMBER: _ClassVar[int]
    MINUTE_OFFSET_GMT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    message_id: str
    utc_seconds: int
    day: int
    month: int
    year: int
    hour_offset_gmt: int
    minute_offset_gmt: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., message_id: _Optional[str] = ..., utc_seconds: _Optional[int] = ..., day: _Optional[int] = ..., month: _Optional[int] = ..., year: _Optional[int] = ..., hour_offset_gmt: _Optional[int] = ..., minute_offset_gmt: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import key_value_pb2 as _key_value_pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Behaviour(_message.Message):
    __slots__ = ("name", "class_name", "own_id", "parent_id", "tip_id", "child_ids", "current_child_id", "type", "additional_detail", "blackbox_level", "status", "message", "is_active", "blackboard_access")
    NAME_FIELD_NUMBER: _ClassVar[int]
    CLASS_NAME_FIELD_NUMBER: _ClassVar[int]
    OWN_ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    TIP_ID_FIELD_NUMBER: _ClassVar[int]
    CHILD_IDS_FIELD_NUMBER: _ClassVar[int]
    CURRENT_CHILD_ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_DETAIL_FIELD_NUMBER: _ClassVar[int]
    BLACKBOX_LEVEL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    BLACKBOARD_ACCESS_FIELD_NUMBER: _ClassVar[int]
    name: str
    class_name: str
    own_id: _uuid_pb2.UUID
    parent_id: _uuid_pb2.UUID
    tip_id: _uuid_pb2.UUID
    child_ids: _containers.RepeatedCompositeFieldContainer[_uuid_pb2.UUID]
    current_child_id: _uuid_pb2.UUID
    type: int
    additional_detail: str
    blackbox_level: int
    status: int
    message: str
    is_active: bool
    blackboard_access: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, name: _Optional[str] = ..., class_name: _Optional[str] = ..., own_id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., parent_id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., tip_id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., child_ids: _Optional[_Iterable[_Union[_uuid_pb2.UUID, _Mapping]]] = ..., current_child_id: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., type: _Optional[int] = ..., additional_detail: _Optional[str] = ..., blackbox_level: _Optional[int] = ..., status: _Optional[int] = ..., message: _Optional[str] = ..., is_active: bool = ..., blackboard_access: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Marker(_message.Message):
    __slots__ = ("ids", "ids_confidence", "pose")
    IDS_FIELD_NUMBER: _ClassVar[int]
    IDS_CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[int]
    ids_confidence: _containers.RepeatedScalarFieldContainer[float]
    pose: _pose_pb2.Pose
    def __init__(self, ids: _Optional[_Iterable[int]] = ..., ids_confidence: _Optional[_Iterable[float]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UserdataInfo(_message.Message):
    __slots__ = ("state", "key", "type", "data")
    STATE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    state: str
    key: str
    type: str
    data: str
    def __init__(self, state: _Optional[str] = ..., key: _Optional[str] = ..., type: _Optional[str] = ..., data: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import point_cloud2_pb2 as _point_cloud2_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Keyframe(_message.Message):
    __slots__ = ("header", "ros2_header", "id", "type", "pointcloud", "pose")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    POINTCLOUD_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    id: int
    type: str
    pointcloud: _point_cloud2_pb2.PointCloud2
    pose: _pose_pb2.Pose
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., id: _Optional[int] = ..., type: _Optional[str] = ..., pointcloud: _Optional[_Union[_point_cloud2_pb2.PointCloud2, _Mapping]] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.cartographer_ros_msgs.msg import status_response_pb2 as _status_response_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FinishTrajectoryRequest(_message.Message):
    __slots__ = ("header", "trajectory_id")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRAJECTORY_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    trajectory_id: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., trajectory_id: _Optional[int] = ...) -> None: ...

class FinishTrajectoryResponse(_message.Message):
    __slots__ = ("header", "status")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    status: _status_response_pb2.StatusResponse
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., status: _Optional[_Union[_status_response_pb2.StatusResponse, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LinkScale(_message.Message):
    __slots__ = ("link_name", "scale")
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    link_name: str
    scale: float
    def __init__(self, link_name: _Optional[str] = ..., scale: _Optional[float] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ListNodesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListNodesResponse(_message.Message):
    __slots__ = ("full_node_names", "unique_ids")
    FULL_NODE_NAMES_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_IDS_FIELD_NUMBER: _ClassVar[int]
    full_node_names: _containers.RepeatedScalarFieldContainer[str]
    unique_ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, full_node_names: _Optional[_Iterable[str]] = ..., unique_ids: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/host_vehicle_state2806.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import ibeo_data_header_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_ibeo__data__header__pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/ibeo_msgs/msg/host_vehicle_state2806.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\x1a\x41make87_messages_ros2/rolling/ibeo_msgs/msg/ibeo_data_header.proto\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xac\x05\n\x14HostVehicleState2806\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12O\n\x0bibeo_header\x18\x02 \x01(\x0b\x32:.make87_messages_ros2.rolling.ibeo_msgs.msg.IbeoDataHeader\x12L\n\ttimestamp\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x12\n\ndistance_x\x18\x04 \x01(\x05\x12\x12\n\ndistance_y\x18\x05 \x01(\x05\x12\x14\n\x0c\x63ourse_angle\x18\x06 \x01(\x02\x12\x1d\n\x15longitudinal_velocity\x18\x07 \x01(\x02\x12\x10\n\x08yaw_rate\x18\x08 \x01(\x02\x12\x1c\n\x14steering_wheel_angle\x18\t \x01(\x02\x12\x1a\n\x12\x63ross_acceleration\x18\n \x01(\x02\x12\x19\n\x11\x66ront_wheel_angle\x18\x0b \x01(\x02\x12\x15\n\rvehicle_width\x18\x0c \x01(\x02\x12#\n\x1bvehicle_front_to_front_axle\x18\r \x01(\x02\x12\x1f\n\x17rear_axle_to_front_axle\x18\x0e \x01(\x02\x12!\n\x19rear_axle_to_vehicle_rear\x18\x0f \x01(\x02\x12\x1a\n\x12steer_ratio_poly_0\x18\x10 \x01(\x02\x12\x1a\n\x12steer_ratio_poly_1\x18\x11 \x01(\x02\x12\x1a\n\x12steer_ratio_poly_2\x18\x12 \x01(\x02\x12\x1a\n\x12steer_ratio_poly_3\x18\x13 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.host_vehicle_state2806_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HOSTVEHICLESTATE2806']._serialized_start=307
  _globals['_HOSTVEHICLESTATE2806']._serialized_end=991
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UlcCmd(_message.Message):
    __slots__ = ("header", "ros2_header", "cmd", "limit_accel", "limit_decel", "limit_jerk_throttle", "limit_jerk_brake", "cmd_type", "enable", "clear", "enable_shift", "enable_shift_park", "coast_decel")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CMD_FIELD_NUMBER: _ClassVar[int]
    LIMIT_ACCEL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_DECEL_FIELD_NUMBER: _ClassVar[int]
    LIMIT_JERK_THROTTLE_FIELD_NUMBER: _ClassVar[int]
    LIMIT_JERK_BRAKE_FIELD_NUMBER: _ClassVar[int]
    CMD_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENABLE_FIELD_NUMBER: _ClassVar[int]
    CLEAR_FIELD_NUMBER: _ClassVar[int]
    ENABLE_SHIFT_FIELD_NUMBER: _ClassVar[int]
    ENABLE_SHIFT_PARK_FIELD_NUMBER: _ClassVar[int]
    COAST_DECEL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    cmd: float
    limit_accel: float
    limit_decel: float
    limit_jerk_throttle: float
    limit_jerk_brake: float
    cmd_type: int
    enable: bool
    clear: bool
    enable_shift: bool
    enable_shift_park: bool
    coast_decel: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., cmd: _Optional[float] = ..., limit_accel: _Optional[float] = ..., limit_decel: _Optional[float] = ..., limit_jerk_throttle: _Optional[float] = ..., limit_jerk_brake: _Optional[float] = ..., cmd_type: _Optional[int] = ..., enable: bool = ..., clear: bool = ..., enable_shift: bool = ..., enable_shift_park: bool = ..., coast_decel: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcss3d_agent_msgs/msg/effector.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import beam_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_beam__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hinge_joint_vel_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_hinge__joint__vel__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import say_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_say__pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import universal_joint_vel_pb2 as make87__messages__ros2_dot_humble_dot_rcss3d__agent__msgs_dot_msg_dot_universal__joint__vel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/humble/rcss3d_agent_msgs/msg/effector.proto\x12\x31make87_messages_ros2.humble.rcss3d_agent_msgs.msg\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/rcss3d_agent_msgs/msg/beam.proto\x1aGmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/hinge_joint_vel.proto\x1a;make87_messages_ros2/humble/rcss3d_agent_msgs/msg/say.proto\x1aKmake87_messages_ros2/humble/rcss3d_agent_msgs/msg/universal_joint_vel.proto\"\x86\x03\n\x08\x45\x66\x66\x65\x63tor\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12Z\n\x10hinge_joint_vels\x18\x02 \x03(\x0b\x32@.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.HingeJointVel\x12\x62\n\x14universal_joint_vels\x18\x03 \x03(\x0b\x32\x44.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.UniversalJointVel\x12\x46\n\x05\x62\x65\x61ms\x18\x04 \x03(\x0b\x32\x37.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Beam\x12\x44\n\x04says\x18\x05 \x03(\x0b\x32\x36.make87_messages_ros2.humble.rcss3d_agent_msgs.msg.Sayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcss3d_agent_msgs.msg.effector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_EFFECTOR']._serialized_start=428
  _globals['_EFFECTOR']._serialized_end=818
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CfgSBAS(_message.Message):
    __slots__ = ("header", "mode", "usage", "max_sbas", "scanmode2", "scanmode1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    USAGE_FIELD_NUMBER: _ClassVar[int]
    MAX_SBAS_FIELD_NUMBER: _ClassVar[int]
    SCANMODE2_FIELD_NUMBER: _ClassVar[int]
    SCANMODE1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mode: int
    usage: int
    max_sbas: int
    scanmode2: int
    scanmode1: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mode: _Optional[int] = ..., usage: _Optional[int] = ..., max_sbas: _Optional[int] = ..., scanmode2: _Optional[int] = ..., scanmode1: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.rcl_interfaces.msg import parameter_value_pb2 as _parameter_value_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParamSetV2Request(_message.Message):
    __slots__ = ("force_set", "param_id", "value")
    FORCE_SET_FIELD_NUMBER: _ClassVar[int]
    PARAM_ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    force_set: bool
    param_id: str
    value: _parameter_value_pb2.ParameterValue
    def __init__(self, force_set: bool = ..., param_id: _Optional[str] = ..., value: _Optional[_Union[_parameter_value_pb2.ParameterValue, _Mapping]] = ...) -> None: ...

class ParamSetV2Response(_message.Message):
    __slots__ = ("success", "value")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    value: _parameter_value_pb2.ParameterValue
    def __init__(self, success: bool = ..., value: _Optional[_Union[_parameter_value_pb2.ParameterValue, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_ack.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import negotiation_participant_ack_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_negotiation__participant__ack__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_ack.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1aQmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/negotiation_participant_ack.proto\"\x8f\x01\n\x0eNegotiationAck\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12\x63\n\x0f\x61\x63knowledgments\x18\x02 \x03(\x0b\x32J.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.NegotiationParticipantAckb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.negotiation_ack_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONACK']._serialized_start=206
  _globals['_NEGOTIATIONACK']._serialized_end=349
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_esf_status.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import esf_sensor_status_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__ubx__msgs_dot_msg_dot_esf__sensor__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_esf_status.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1aGmake87_messages_ros2/rolling/ublox_ubx_msgs/msg/esf_sensor_status.proto\"\xd4\x02\n\x0cUBXEsfStatus\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0c\n\x04itow\x18\x02 \x01(\r\x12\x0f\n\x07version\x18\x03 \x01(\r\x12\x16\n\x0ewt_init_status\x18\x04 \x01(\r\x12\x16\n\x0emnt_alg_status\x18\x05 \x01(\r\x12\x17\n\x0fins_init_status\x18\x06 \x01(\r\x12\x17\n\x0fimu_init_status\x18\x07 \x01(\r\x12\x13\n\x0b\x66usion_mode\x18\x08 \x01(\r\x12\x10\n\x08num_sens\x18\t \x01(\r\x12Y\n\x0fsensor_statuses\x18\n \x03(\x0b\x32@.make87_messages_ros2.rolling.ublox_ubx_msgs.msg.ESFSensorStatusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.ubx_esf_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_UBXESFSTATUS']._serialized_start=251
  _globals['_UBXESFSTATUS']._serialized_end=591
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.novatel_gps_msgs.msg import trackstat_channel_pb2 as _trackstat_channel_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Trackstat(_message.Message):
    __slots__ = ("header", "solution_status", "position_type", "cutoff", "channels")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SOLUTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    POSITION_TYPE_FIELD_NUMBER: _ClassVar[int]
    CUTOFF_FIELD_NUMBER: _ClassVar[int]
    CHANNELS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    solution_status: str
    position_type: str
    cutoff: float
    channels: _containers.RepeatedCompositeFieldContainer[_trackstat_channel_pb2.TrackstatChannel]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., solution_status: _Optional[str] = ..., position_type: _Optional[str] = ..., cutoff: _Optional[float] = ..., channels: _Optional[_Iterable[_Union[_trackstat_channel_pb2.TrackstatChannel, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_query_participants_pb2 as _schedule_query_participants_pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import schedule_query_spacetime_pb2 as _schedule_query_spacetime_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduleQuery(_message.Message):
    __slots__ = ("spacetime", "participants")
    SPACETIME_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    spacetime: _schedule_query_spacetime_pb2.ScheduleQuerySpacetime
    participants: _schedule_query_participants_pb2.ScheduleQueryParticipants
    def __init__(self, spacetime: _Optional[_Union[_schedule_query_spacetime_pb2.ScheduleQuerySpacetime, _Mapping]] = ..., participants: _Optional[_Union[_schedule_query_participants_pb2.ScheduleQueryParticipants, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SnapshotStreamParameters(_message.Message):
    __slots__ = ("header", "snapshot_period", "blackboard_data", "blackboard_activity")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SNAPSHOT_PERIOD_FIELD_NUMBER: _ClassVar[int]
    BLACKBOARD_DATA_FIELD_NUMBER: _ClassVar[int]
    BLACKBOARD_ACTIVITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    snapshot_period: float
    blackboard_data: bool
    blackboard_activity: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., snapshot_period: _Optional[float] = ..., blackboard_data: bool = ..., blackboard_activity: bool = ...) -> None: ...
